"""
Expander - a module for dealing with expansion of ENV vars in a secret
reference URI.
"""
import os
from typing import Callable


_ENV_VAR_SYNTAX: str = "$"

def expand_env_vars(
    shell_command: Callable[[str], str],
    secret_reference: str
) -> str:
    """
    Expands env vars in a secret reference. Returns immediately if no env vars
    contained in secret reference string.
    """
    if not _ENV_VAR_SYNTAX in secret_reference:
        return secret_reference

    command: str = shell_command(secret_reference)
    expanded: str = os.popen(command).read().strip()

    return expanded



"""
Module to initialise a 1Password client
"""
from onepassword.client import Client

from ..__version__ import __version__


_INTEGRATION_NAME: str = "Plover 1Password plugin integration"

async def init_client(service_account_token: str) -> Client:
    """
    Initialises a 1Password client to retrieve secrets.
    """
    client: Client = await Client.authenticate(
        auth=service_account_token,
        integration_name=_INTEGRATION_NAME,
        integration_version=__version__
    )

    return client



"""
Token - Module concerning retrieving a token value for a 1Password Service
Account
"""
import os
from typing import (
    Callable,
    Optional
)

_POWERSHELL_TOKEN_ENV_VAR_NAME: str = "$ENV:OP_SERVICE_ACCOUNT_TOKEN"
_SHELL_TOKEN_ENV_VAR_NAME: str = "$OP_SERVICE_ACCOUNT_TOKEN"

def get_token(platform: str, shell_command: Callable[[str], str]) -> str:
    """
    Returns token from the local environment and errors if it is empty.
    """
    token_env_var_name: str
    if platform == "Windows":
        token_env_var_name = _POWERSHELL_TOKEN_ENV_VAR_NAME
    else:
        token_env_var_name = _SHELL_TOKEN_ENV_VAR_NAME

    command: str = shell_command(token_env_var_name)
    token: Optional[str] = os.popen(command).read().strip()

    if not token:
        raise ValueError(f"No value found for {token_env_var_name}")

    return token
